@@ -6,6 +6,12 @@ from halig.settings import Settings
 
 
 class Encryptor:
+    """Encryption utility class
+
+    Attributes:
+        settings (Settings): a Settings instance
+    """
+
     def __init__(self, settings: Settings):
         self.settings = settings
 
