@@ -3,11 +3,24 @@ from functools import lru_cache
 from pathlib import Path
 
 import yaml
-from pydantic import BaseSettings, FilePath
+from pydantic import BaseSettings, DirectoryPath, FilePath
 
 
 class Settings(BaseSettings):
-    notebooks_root_path: Path
+    """Settings model. It mainly stores paths that are interesting to the project.
+     All the path-attributes described below have a validity check upon instantiation,
+     meaning that they should exist and be readable and/or writable
+
+    Attributes:
+        notebooks_root_path (DirectoryPath): a *valid* path to a directory that
+            may contain notes or other notebooks
+        identity_path (FilePath): a *valid* path to an identity file, which usually
+            is understood as a private key. Defaults to `~/.ssh/id_ed25519`
+        recipient_path (FilePath): a *valid* path to a recipient file, which usually
+            is understood as a public key. Defaults to `~/.ssh/id_ed25519.pub`
+    """
+
+    notebooks_root_path: DirectoryPath
     identity_path: FilePath = Path("~/.ssh/id_ed25519").expanduser()
     recipient_path: FilePath = Path("~/.ssh/id_ed25519.pub").expanduser()
 
